/* 
 * DB Export Script - Function Definitions (db-export-func-defs.js)
 * Copyright (C) 2013 Gideon Messer - CC-BY-3.0
 * This file is licensed under Creative Commons Attribution 3.0 Unported
 * http://creativecommons.org/licenses/by/3.0/
 * Other included code attributed as marked.
 */

// Generic function to display errors to the user.
function ErrorBox(e) {
	var wshShell = WScript.CreateObject("WScript.Shell");
	wshShell.Popup(e.message, 0, e.name, 
		objMsgBox.BtnTypes.OK.value + objMsgBox.IconTypes.Exclamation.value);
}

function ExportHandler() {
	// Database
	var _strProvider;
	var _strDBFileDir;
	var _strDBFilename;
	var _strTableName;
	
	var _objConnection;
	var _objFieldList;
	var _objRecordSet;

	// Temp Data Variable
	var _objTempDataVar;
	var _strOutput;
	
	// Output File
	var _objOutputStream;
	var _objTemplateStream;
	var _strOutputFileDir;
	var _strOutputFilename;

	var that = this;
	
	/* Accessor and Mutator Functions */
	// Set the provider.
	this.SetProvider = function (strProvider) {
		if (typeof strProvider !== "string") {
			throw new TypeError("The argument must be a string");
		} else if (strProvider === "") {
			throw new IncorrectSettingError("A database provider must be set.");
		} else {
			that._strProvider = strProvider;
		}
	}
	
	// Set the database file source directory.
	this.SetDBFileDir = function (strDBFileDir) {
		if (typeof strDBFileDir !== "string") {
			throw new TypeError("The argument must be a string.");
		} else {
			that._strDBFileDir = strDBFileDir;
		}
	}
	
	// Set the database source filename.
	this.SetDBFilename = function (strDBFilename) {
		if (typeof strDBFilename !== "string") {
			throw new TypeError("The argument must be a string.");
		} else if (strDBFilename == "") {
			throw new IncorrectSettingError("You must enter a value for the database filename.");
		} else {
			that._strDBFilename = strDBFilename;
		}
	}
	
	// Set the database source table name.
	this.SetTableName = function (strTableName) {
		if (typeof strTableName !== "string") {
			throw new TypeError("The argument must be a string.");
		} else if (strTableName === "") {
			throw new IncorrectSettingError("You must enter a value for the database table name.");
		} else {
			that._strTableName = strTableName;
		}
	}
	
	// Set the output file directory.
	this.SetOutputFileDir = function (strOutputFileDir) {
		if (typeof strOutputFileDir !== "string") {
			throw new TypeError("The argument must be a string.");
		} else if (strOutputFileDir == "") {
			that._strOutputFileDir = that._strDBFileDir;
		} else {
			that._strOutputFileDir = strOutputFileDir;
		}
	}
	
	// Set the output filename.
	this.SetOutputFilename = function (strOutputFilename) {
		if (typeof strOutputFilename !== "string") {
			throw new TypeError("The argument must be a string.");
		} else if (strOutputFilename === "") {
			throw new IncorrectSettingError("You must enter a value for the output filename.");
		} else {
			that._strOutputFilename = strOutputFilename;
		}
	}
	
	/* Action Functions */

	// Open a connection to the DB and prepare to read the records from the table.
	this.OpenDB = function () {
		// Create the connection object.
		that._objConnection = new ActiveXObject("ADODB.Connection");
		
		// Create an object to hold the current record.
		that._objRecordSet = new ActiveXObject("ADODB.Recordset");
		
		// Open the connection to the database.
		that._objConnection.Open(
			"Provider=" + that._strProvider + "; " +
			"Data Source=" + that._strDBFileDir + that._strDBFilename);
	}
	
	// Read all records from the specified database table.
	this.ReadDBRecords = function () {
		// Retrieve a set of from the open database.
		that._objRecordSet.Open("SELECT * FROM [" + that._strTableName + "]", 
			that._objConnection, ADOCursorType.OpenForwardOnly.value, ADOLockType.LockReadOnly.value);
		
		var objTmp;
		that._objTempDataVar = new Array();
		for (that._objRecordSet.MoveFirst(); !that._objRecordSet.EOF; that._objRecordSet.MoveNext()) {
			objTmp = new Object();
			var eRS = new Enumerator(that._objRecordSet.Fields);
			for (eRS.moveFirst(); !eRS.atEnd(); eRS.moveNext()) {
				switch (typeof eRS.item().value) {
					case "date":
						// Convert the ActiveX date object to a standard JS Date object.
						var fileDate = new Date(eRS.item().value);
						objTmp[eRS.item().name] = fileDate.toDateString();
						break;
					case "unknown":
						// Regularized the handling of special cases.
						objTmp[eRS.item().name] = null;
						break;
					default:
						objTmp[eRS.item().name] = eRS.item().value;
				}
			}
			that._objTempDataVar.push(objTmp);
		}
	}

	// Close the record set's connection the database.
	this.CloseRS = function() {
		that._objRecordSet.Close();
	}
	
	// Close the connection to the database.
	this.CloseDB = function () {
		that._objConnection.Close();
	}
	
	// Open a handle to the template file.
	this.OpenTemplateFile = function () {
		var objFS = new ActiveXObject("Scripting.FileSystemObject");
		that._objTemplateStream = objFS.OpenTextFile("output-template.html", 1);
	}

	// Read the template file and replace the placeholder tokens with data.
	this.ReadTemplateFile = function () {
		that._strOutput = that._objTemplateStream.ReadAll();
		that._strOutput = that._strOutput.replace("{TITLE}", that._strTableName);
		that._strOutput = that._strOutput.replace("{DATA}", JSON.stringify(that._objTempDataVar, null, "    "));
	}
	
	// Close the template file.
	this.CloseTemplateFile = function () {
		that._objTemplateStream.Close();
	}
	
	// Open a handle to the output file.
	this.OpenOutputFile = function () {
		var objFS = new ActiveXObject("Scripting.FileSystemObject");
		that._objOutputStream = objFS.CreateTextFile(that._strOutputFileDir + that._strOutputFilename, 2, 0);
	}
	
	// Write all records to the output file.
	this.WriteRecordsToFile = function () {
		that._objOutputStream.Write(that._strOutput);
	}
	
	// Close the output file.
	this.CloseOutputFile = function () {
		that._objOutputStream.Close();
	}
}

