/* 
 * DB Export Script - Objects File (db-export-obj.js)
 * Copyright (C) 2013 Gideon Messer - CC-BY-3.0
 * This file is licensed under Creative Commons Attribution 3.0 Unported
 * http://creativecommons.org/licenses/by/3.0/
 * Other included code attributed as marked.
 */

/* MessageBox properties.
 * Class information from MSDN pages at
 * http://msdn.microsoft.com/en-us/library/x83z1d9f.aspx (for JS reference), and
 * http://msdn.microsoft.com/en-us/library/ms645505%28VS.85%29.aspx (for C++ full class reference).
 */
var objMsgBox = {
	// Button Types
	BtnTypes: {
		OK:                {value: 0x00, name: "OK"               },
		OKCancel:          {value: 0x01, name: "OKCancel"         },
		AbortRetryIgnore:  {value: 0x02, name: "AbortRetryIgnore" },
		YesNoCancel:       {value: 0x03, name: "YesNoCancel"      },
		YesNo:             {value: 0x04, name: "YesNo"            },
		RetryCancel:       {value: 0x05, name: "RetryCancel"      },
		CancelTryContinue: {value: 0x06, name: "CancelTryContinue"}
	},
	
	// Icon Types
	IconTypes: {
		Stop:        {value: 0x10, name: "Stop"       },
		Question:    {value: 0x20, name: "Question"   },
		Exclamation: {value: 0x30, name: "Exclamation"},
		Information: {value: 0x40, name: "Information"}
	},
	
	// Default Buttons
	DefaultBtn: {
		Btn1: {value: 0x00, name: "DefaultBtn1"},
		Btn2: {value: 0x10, name: "DefaultBtn2"},
		Btn3: {value: 0x20, name: "DefaultBtn3"},
		Btn4: {value: 0x30, name: "DefaultBtn4"}
	},
	
	// MessageBox Modality
	Modality: {
		App: {value: 0x0000, name: "ApplicationModality"},
		Sys: {value: 0x1000, name: "SystemModality"     }
	},
	
	// Return Values
	RetVals: {
		BtnNoSelection: {value:-1, name:"NoSelection"},
		BtnOk:          {value: 1, name:"Ok"         },
		BtnCancel:      {value: 2, name:"Cancel"     },
		BtnAbort:       {value: 3, name:"Abort"      },
		BtnRetry:       {value: 4, name:"Retry"      },
		BtnIgnore:      {value: 5, name:"Ignore"     },
		BtnYes:         {value: 6, name:"Yes"        },
		BtnNo:          {value: 7, name:"No"         },
		BtnTryAgain:    {value:10, name:"TryAgain"   },
		BtnContinue:    {value:11, name:"Continue"   }
	}
};

// The following objects are enumerations, but only contain a few of the values
// from the actual enumerations. They are included here to improve code 
// readability in the ExportHandler class.

// This object contains cursor types when calling the ADO RecordSet.Open() method.
// Data from http://www.w3schools.com/ado/met_rs_open.asp#CursorTypeEnum
var ADOCursorType = {
	/*	Default. A forward-only cursor. This improves performance
		when you need to make only one pass through a Recordset.	*/
	OpenForwardOnly: {value:0, name:"OpenForwardOnly"}
};

// This object contains lock types used when calling the ADO RecordSet.Open() method.
// Data from http://www.w3schools.com/ado/met_rs_open.asp#LockTypeEnum
var ADOLockType = {
	/*	Default. Read-only records.									*/
	LockReadOnly: {value:1, name:"LockReadOnly"}
};

// This object contains information about which schema query to run.
// Data from http://www.w3schools.com/ado/met_conn_openschema.asp#schemaenum
var ADOSchema = {
	/*	Returns the columns of tables defined in the catalog		*/
	SchemaColumns: {value:4, name:"SchemaColumns"}
};

/* Errors inherit prototypically from the Error object. */
// Based on information and code from 
// https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Error

// Defines an exception for invalid settings.
function IncorrectSettingError(message) {
  this.name = "InvalidSettingError";
  this.message = message || "Invalid setting";
}
IncorrectSettingError.prototype = new Error();
IncorrectSettingError.prototype.constructor = IncorrectSettingError;

